@@ -27,27 +27,27 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   HTML
- * @package    Pager
- * @author     Lorenzo Alberton <l dot alberton at quipo dot it>
- * @author     Richard Heyes <richard@phpguru.org>
- * @copyright  2003-2006 Lorenzo Alberton, Richard Heyes
- * @license    http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
- * @version    CVS: $Id: Pager.php,v 1.21 2006/05/22 10:29:26 quipo Exp $
- * @link       http://pear.php.net/package/Pager
+ * @category  HTML
+ * @package   Pager
+ * @author    Lorenzo Alberton <l.alberton@quipo.it>
+ * @author    Richard Heyes <richard@phpguru.org>
+ * @copyright 2003-2008 Lorenzo Alberton, Richard Heyes
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @version   CVS: $Id: Pager.php,v 1.26 2008/02/02 16:55:04 quipo Exp $
+ * @link      http://pear.php.net/package/Pager
  */
 
 /**
  * Pager - Wrapper class for [Sliding|Jumping]-window Pager
  * Usage examples can be found in the PEAR manual
  *
- * @category   HTML
- * @package    Pager
- * @author     Lorenzo Alberton <l dot alberton at quipo dot it>
- * @author     Richard Heyes <richard@phpguru.org>,
- * @copyright  2003-2005 Lorenzo Alberton, Richard Heyes
- * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @link       http://pear.php.net/package/Pager
+ * @category  HTML
+ * @package   Pager
+ * @author    Lorenzo Alberton <l.alberton@quipo.it>
+ * @author    Richard Heyes <richard@phpguru.org>
+ * @copyright 2003-2008 Lorenzo Alberton, Richard Heyes
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @link      http://pear.php.net/package/Pager
  */
 class Pager
 {
@@ -134,8 +134,8 @@ class Pager
      *  - itemData OR totalItems (if itemData is set, totalItems is overwritten)
      * -------------------------------------------------------------------------
      *
-     * @param mixed $options    An associative array of option names and
-     *                          their values.
+     * @param mixed $options Associative array of option names and their values
+     *
      * @access public
      */
     function Pager($options = array())
@@ -160,8 +160,9 @@ class Pager
     /**
      * Return a pager based on $mode and $options
      *
-     * @param  array $options Optional parameters for the storage class
-     * @return object Object   Storage object
+     * @param array $options Optional parameters for the storage class
+     *
+     * @return object Storage object
      * @static
      * @access public
      */
@@ -180,7 +181,7 @@ class Pager
 
         // If the class exists, return a new instance of it.
         if (class_exists($classname)) {
-            $pager =& new $classname($options);
+            $pager = new $classname($options);
             return $pager;
         }
 
