@@ -1,5 +1,5 @@
 <?php
-// CVS: $Id: Pager_Wrapper.php,v 1.22 2006/03/15 12:29:57 quipo Exp $
+// CVS: $Id: Pager_Wrapper.php,v 1.23 2006/12/12 17:25:50 quipo Exp $
 //
 // Pager_Wrapper
 // -------------
@@ -40,7 +40,9 @@
  */
 function rewriteCountQuery($sql)
 {
-    if (preg_match('/^\s*SELECT\s+\bDISTINCT\b/is', $sql) || preg_match('/\s+GROUP\s+BY\s+/is', $sql)) {
+    if (preg_match('/^\s*SELECT\s+\bDISTINCT\b/is', $sql) ||
+        preg_match('/\s+GROUP\s+BY\s+/is', $sql) ||
+        preg_match('/\s+UNION\s+/is', $sql)) {
         return false;
     }
     $open_parenthesis = '(?:\()';
