@@ -1,5 +1,5 @@
 <?php
-// $Id: pager_jumping_tests.php,v 1.1 2003/11/30 17:30:01 quipo Exp $
+// $Id: pager_jumping_tests.php,v 1.2 2008/11/14 15:46:33 quipo Exp $
 
 require_once 'simple_include.php';
 require_once 'pager_include.php';
@@ -14,7 +14,7 @@ class PagerJumpingTests extends GroupTest {
 
 if (!defined('TEST_RUNNING')) {
     define('TEST_RUNNING', true);
-    $test = &new PagerTests();
+    $test = new PagerTests();
     $test->run(new HtmlReporter());
 }
 ?>
\ No newline at end of file
