@@ -1,5 +1,5 @@
 <?php
-// $Id: pager_test.php,v 1.31 2008/03/26 21:54:10 quipo Exp $
+// $Id: pager_test.php,v 1.35 2008/05/31 12:45:25 quipo Exp $
 
 require_once 'simple_include.php';
 require_once 'pager_include.php';
@@ -21,28 +21,28 @@ class TestOfPager extends UnitTestCase {
     function tearDown() {
         unset($this->pager);
     }
-    function testCurrentPageID () {
+    function testCurrentPageID() {
         $this->assertEqual(1, $this->pager->getCurrentPageID());
     }
-    function testNextPageID () {
+    function testNextPageID() {
         $this->assertEqual(2, $this->pager->getNextPageID());
     }
-    function testPrevPageID () {
+    function testPrevPageID() {
         $this->assertEqual(false, $this->pager->getPreviousPageID());
     }
-    function testNumItems () {
+    function testNumItems() {
         $this->assertEqual(10, $this->pager->numItems());
     }
-    function testNumPages () {
+    function testNumPages() {
         $this->assertEqual(2, $this->pager->numPages());
     }
-    function testFirstPage () {
+    function testFirstPage() {
         $this->assertEqual(true, $this->pager->isFirstPage());
     }
-    function testLastPage () {
+    function testLastPage() {
         $this->assertEqual(false, $this->pager->isLastPage());
     }
-    function testLastPageComplete () {
+    function testLastPageComplete() {
         $this->assertEqual(true, $this->pager->isLastPageComplete());
     }
     function testOffsetByPageId() {
@@ -175,6 +175,9 @@ class TestOfPager extends UnitTestCase {
         //$this->assertEqual($expected, $this->pager->_getLinksUrl());
 
         $expected = 'request%5B0%5D=aRequest&amp;escape=%E4%F6%25%3C%3E%2B';
+        if (1 == version_compare(PHP_VERSION, '5.2.99')) {
+            $expected = 'request%5B0%5D=aRequest&amp;escape=%C3%A4%C3%B6%25%3C%3E%2B';
+        }
         $rendered = $this->pager->_renderLink('', '');
         preg_match('/href="(.*)"/U', $rendered, $matches);
         $actual = str_replace($_SERVER['PHP_SELF'].'?', '', $matches[1]);
@@ -208,6 +211,20 @@ class TestOfPager extends UnitTestCase {
         $actual = str_replace($_SERVER['PHP_SELF'].'?test=', '', $matches[1]);
         $this->assertEqual(urlencode($options['extraVars']['test']), $actual);
     }
+    function testMultibyteJapaneseStrings() {
+        $options = array(
+            'extraVars' => array(
+                'test' => '&#28450;&#23383;',
+            ),
+            'perPage' => 5,
+        );
+        $this->pager =& Pager::factory($options);
+        //$expected = '<a href="'.$_SERVER['PHP_SELF'].'?test=&#27979;&#35797;" title=""></a>';
+        $rendered = $this->pager->_renderLink('', '');
+        preg_match('/href="(.*)"/U', $rendered, $matches);
+        $actual = str_replace($_SERVER['PHP_SELF'].'?test=', '', $matches[1]);
+        $this->assertEqual(urlencode($options['extraVars']['test']), $actual);
+    }
     function testCurrentPage() {
         $options = array(
             'itemData'    => array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10),
@@ -247,15 +264,23 @@ class TestOfPager extends UnitTestCase {
         $this->assertEqual($expected, $actual);
     }
     function testExcludeVars() {
-        $arr = array(
-            'apple',
-            'orange',
+        $_GET['excludeMe'] = 'foo';
+        $extraVars = array(
+            'arr' => array(
+                'apple',
+                'orange',
+            ),
+            'no' => 'test', // do not remove this one, because it has been explicitely added
+        );
+        $excludeVars = array(
+            'no',        // do not remove, @see above
+            'excludeMe', //remove
         );
         $options = array(
             'itemData'    => array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10),
             'perPage'     => 5,
-            'extraVars'   => array('arr' => $arr, 'no' => 'test'),
-            'excludeVars' => array('no'),
+            'extraVars'   => $extraVars,
+            'excludeVars' => $excludeVars,
         );
         $this->pager =& Pager::factory($options);
         $expected = array(
@@ -266,14 +291,45 @@ class TestOfPager extends UnitTestCase {
             'no' => 'test',
         );
         $actual = $this->pager->_getLinksData();
-        $this->assertEqual($expected, $this->pager->_getLinksData());
+        $this->assertEqual($expected, $actual);
         $separator = ini_get('arg_separator.output');
         if ($separator == '&') {
             $separator = '&amp;';
         }
+
         $expected = '<a href="'.$_SERVER['PHP_SELF'].'?arr%5B0%5D=apple'.$separator.'arr%5B1%5D=orange'.$separator.'no=test'.$separator.'pageID=2" title=""></a>';
         $actual = $this->pager->_renderLink('', '');
         $this->assertEqual($expected, $actual);
+        unset($_GET['excludeMe']); //cleanup
+
+        //exclude with regexp
+
+        $_GET['reMoveAAA'] = 'aaa';
+        $_GET['RemoveBBB'] = 'bbb';
+        $_GET['leaveCCC']  = 'ccc';
+        $excludeVars = array(
+            '/remove.*/i', //regexp
+        );
+        $options = array(
+            'itemData'    => array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10),
+            'perPage'     => 5,
+            'extraVars'   => $extraVars,
+            'excludeVars' => $excludeVars,
+        );
+        $this->pager =& Pager::factory($options);
+        $expected = array(
+            'arr' => array(
+                0 => 'apple',
+                1 => 'orange'
+            ),
+            'no' => 'test',
+            'leaveCCC'  => 'ccc',
+        );
+        $this->assertEqual($expected, $this->pager->_getLinksData());
+        //cleanup
+        foreach (array_keys($_GET) as $k) {
+        	unset($_GET[$k]);
+        }
     }
     function testArgSeparator() {
         $bkp_arg_separator = ini_get('arg_separator.output');
@@ -580,7 +636,7 @@ class TestOfPager extends UnitTestCase {
             'accesskey' => true,
         );
         $this->pager = Pager::factory($options);
-        $this->assertWantedPattern('/accesskey="\d"/i', $this->pager->links);
+        $this->assertPattern('/accesskey="\d"/i', $this->pager->links);
         //var_dump($this->pager->links);
     }
     function testIsEncoded() {
@@ -665,5 +721,50 @@ class TestOfPager extends UnitTestCase {
         $expected = '<a href="' . $_SERVER['PHP_SELF'] . '?pageID=2" title="next page">&raquo;</a>';
         $this->assertEqual($expected, $this->pager->_getNextLink());
     }
+    //http://pear.php.net/bugs/bug.php?id=12306
+    function testAbsoluteLinks() {
+        // Reproduces bug #13881
+        $options = array (
+            'mode' => 'Sliding',
+            'delta' => 5,
+            'totalItems' => 50,
+            'perPage' => 10,
+            'urlVar' => 'page',
+            'currentPage' => 1,
+            'append' => false,
+            'path' => '',
+            'fileName' => '/report/alpha/page/%d/orderBy/foo/direction/asc',
+            'spacesBeforeSeparator' => 0,
+            'spacesAfterSeparator'  => 0,
+        );
+        $this->pager = Pager::factory($options);
+        $this->pager->build();
+        $expected = '<a href="/report/alpha/page/2/orderBy/foo/direction/asc" title="next page">&raquo;</a>';
+        $this->assertEqual($expected, $this->pager->_getNextLink());
+
+        $options['path'] = '/';
+        $options['fileName'] = '/report/alpha/page/%d/orderBy/foo/direction/asc';
+        $this->pager = Pager::factory($options);
+        $this->pager->build();
+        $expected = '<a href="/report/alpha/page/2/orderBy/foo/direction/asc" title="next page">&raquo;</a>';
+        $this->assertEqual($expected, $this->pager->_getNextLink());
+    }
+    //http://pear.php.net/bugs/bug.php?id=13913
+    function testEmptyPagerWithImgEmpty() {
+        $options = array(
+            'itemData' => range(1, 2),
+            'perPage'  => 5,
+            'prevImgEmpty' => 'YYY',
+            'nextImgEmpty' => 'XXX',
+        );
+        $this->pager = Pager::factory($options);
+        $expected = '';
+        $this->assertEqual($expected, $this->pager->links);
+    }
+}
+if (!defined('TEST_RUNNING')) {
+    define('TEST_RUNNING', true);
+    $test = new TestOfPager();
+    $test->run(new HtmlReporter());
 }
 ?>
\ No newline at end of file
