@@ -1,5 +1,5 @@
 <?php
-// $Id: pager_wrapper_test.php,v 1.2 2006/03/15 12:29:57 quipo Exp $
+// $Id: pager_wrapper_test.php,v 1.3 2006/12/12 17:25:50 quipo Exp $
 
 require_once 'simple_include.php';
 require_once 'pager_wrapper_include.php';
@@ -45,6 +45,10 @@ class TestOfPagerWrapper extends UnitTestCase
         $query = 'SELECT DISTINCT a, b, c, d FROM  mytable WHERE a=1 GROUP BY c';
         $this->assertFalse(rewriteCountQuery($query));
 
+        //test UNION
+        $query = 'SELECT a FROM mytable1 UNION SELECT a FROM mytable2';
+        $this->assertFalse(rewriteCountQuery($query));
+
         //test MiXeD Keyword CaSe
         $query = 'SELECT a, b, c, d from mytable WHERE a=1 AND c="g"';
         $expected = 'SELECT COUNT(*) FROM mytable WHERE a=1 AND c="g"';
